# Class: event

Asynchronous event registration and handling

## Fields for class: event

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`class`             |`string`            |_RO/constructor_|The name of the class of the object that changed|
|`id`                |`int`               |_RO/constructor_|An ID, monotonically increasing, and local to the current session|
|`obj_uuid`          |`string`            |_RO/constructor_|**Deprecated.** The uuid of the object that changed     |
|`operation`         |`event_operation`   |_RO/constructor_|The operation that was performed        |
|`ref`               |`string`            |_RO/constructor_|A reference to the object that changed  |
|`timestamp`         |`datetime`          |_RO/constructor_|**Deprecated.** The time at which the event occurred    |
|snapshot            |object record       |_RO/runtime_   |The record of the database object that was added, changed or deleted|

## RPCs associated with class: event

### RPC name: from

_Overview:_

Blocking call which returns a new token and a &#40;possibly empty&#41; batch of events. The returned token can be used in subsequent calls to this function. It eliminates redundant events &#40;e.g. same field updated multiple times&#41;.

_Signature:_

```
event batch from (session ref session_ref, string set classes, string token, float timeout)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string set`                  |`classes`                     |register for events for the indicated classes|
|`string`                      |`token`                       |A token representing the point from which to generate database events. The empty string represents the beginning.|
|`float`                       |`timeout`                     |Return after this many seconds if no events match|

_Minimum Role:_ read-only

_Return Type:_ `event batch`

a structure consisting of a token &#40;'token'&#41;, a map of valid references per object type &#40;'valid&#95;ref&#95;counts'&#41;, and a set of event records &#40;'events'&#41;.

_Possible Error Codes:_ `EVENT_FROM_TOKEN_PARSE_FAILURE`, `EVENT_SUBSCRIPTION_PARSE_FAILURE`

### RPC name: get&#95;current&#95;id

_Overview:_

Return the ID of the next event to be generated by the system

_Signature:_

```
int get_current_id (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `int`

the event ID

### RPC name: inject

_Overview:_

Injects an artificial event on the given object and returns the corresponding ID in the form of a token, which can be used as a point of reference for database events. For example, to check whether an object has reached the right state before attempting an operation, one can inject an artificial event on the object and wait until the token returned by consecutive event.from calls is lexicographically greater than the one returned by event.inject.

_Signature:_

```
string inject (session ref session_ref, string class, string ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`class`                       |class of the object                     |
|`string`                      |`ref`                         |A reference to the object that will be changed.|

_Minimum Role:_ read-only

_Return Type:_ `string`

the event ID in the form of a token

### RPC name: next

**This message is deprecated.**

_Overview:_

Blocking call which returns a &#40;possibly empty&#41; batch of events. This method is only recommended for legacy use.It stores events in a buffer of limited size, raising EVENTS&#95;LOST if too many events got generated. New development should use event.from which supersedes this method.

_Signature:_

```
event record set next (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `event record set`

A set of events

_Possible Error Codes:_ `SESSION_NOT_REGISTERED`, `EVENTS_LOST`, `EVENT_SUBSCRIPTION_PARSE_FAILURE`

### RPC name: register

**This message is deprecated.**

_Overview:_

Registers this session with the event system for a set of given classes. This method is only recommended for legacy use in conjunction with event.next.

_Signature:_

```
void register (session ref session_ref, string set classes)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string set`                  |`classes`                     |the classes for which the session will register with the event system; specifying &#42; as the desired class will register for all classes|

_Minimum Role:_ read-only

_Return Type:_ `void`

### RPC name: unregister

**This message is deprecated.**

_Overview:_

Removes this session's registration with the event system for a set of given classes. This method is only recommended for legacy use in conjunction with event.next.

_Signature:_

```
void unregister (session ref session_ref, string set classes)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string set`                  |`classes`                     |the classes for which the session's registration with the event system will be removed|

_Minimum Role:_ read-only

_Return Type:_ `void`
