# Class: network&#95;sriov

network&#45;sriov which connects logical pif and physical pif

## Fields for class: network&#95;sriov

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`configuration_mode`|`sriov_configuration_mode`|_RO/runtime_   |The mode for configure network sriov    |
|`logical_PIF`       |`PIF ref`           |_RO/constructor_|The logical PIF to connect to the SR&#45;IOV network after enable SR&#45;IOV on the physical PIF|
|`physical_PIF`      |`PIF ref`           |_RO/constructor_|The PIF that has SR&#45;IOV enabled     |
|`requires_reboot`   |`bool`              |_RO/runtime_   |Indicates whether the host need to be rebooted before SR&#45;IOV is enabled on the physical PIF|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: network&#95;sriov

### RPC name: create

_Overview:_

Enable SR&#45;IOV on the specific PIF. It will create a network&#45;sriov based on the specific PIF and automatically create a logical PIF to connect the specific network.

_Signature:_

```
network_sriov ref create (session ref session_ref, PIF ref pif, network ref network)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`pif`                         |PIF on which to enable SR&#45;IOV       |
|`network ref`                 |`network`                     |Network to connect SR&#45;IOV virtual functions with VM VIFs|

_Minimum Role:_ pool-operator

_Return Type:_ `network_sriov ref`

The reference of the created network&#95;sriov object

### RPC name: destroy

_Overview:_

Disable SR&#45;IOV on the specific PIF. It will destroy the network&#45;sriov and the logical PIF accordingly.

_Signature:_

```
void destroy (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |SRIOV to destroy                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the network&#95;sriovs known to the system.

_Signature:_

```
network_sriov ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of network&#95;sriov references to network&#95;sriov records for all network&#95;sriovs known to the system.

_Signature:_

```
(network_sriov ref -> network_sriov record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(network_sriov ref -> network_sriov record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the network&#95;sriov instance with the specified UUID.

_Signature:_

```
network_sriov ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref`

reference to the object

### RPC name: get&#95;configuration&#95;mode

_Overview:_

Get the configuration&#95;mode field of the given network&#95;sriov.

_Signature:_

```
sriov_configuration_mode get_configuration_mode (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `sriov_configuration_mode`

value of the field

### RPC name: get&#95;logical&#95;PIF

_Overview:_

Get the logical&#95;PIF field of the given network&#95;sriov.

_Signature:_

```
PIF ref get_logical_PIF (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;physical&#95;PIF

_Overview:_

Get the physical&#95;PIF field of the given network&#95;sriov.

_Signature:_

```
PIF ref get_physical_PIF (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given network&#95;sriov.

_Signature:_

```
network_sriov record get_record (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov record`

all fields from the object

### RPC name: get&#95;remaining&#95;capacity

_Overview:_

Get the number of free SR&#45;IOV VFs on the associated PIF

_Signature:_

```
int get_remaining_capacity (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |the NETWORK&#95;SRIOV object            |

_Minimum Role:_ read-only

_Return Type:_ `int`

The number of free SR&#45;IOV VFs on the associated PIF

### RPC name: get&#95;requires&#95;reboot

_Overview:_

Get the requires&#95;reboot field of the given network&#95;sriov.

_Signature:_

```
bool get_requires_reboot (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given network&#95;sriov.

_Signature:_

```
string get_uuid (session ref session_ref, network_sriov ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network_sriov ref`           |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field
