# Class: PVS&#95;cache&#95;storage

Describes the storage that is available to a PVS site for caching purposes

## Fields for class: PVS&#95;cache&#95;storage

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`host`              |`host ref`          |_RO/constructor_|The host on which this object defines PVS cache storage|
|`site`              |`PVS_site ref`      |_RO/constructor_|The PVS&#95;site for which this object defines the storage|
|`size`              |`int`               |_RO/constructor_|The size of the cache VDI &#40;in bytes&#41;|
|`SR`                |`SR ref`            |_RO/constructor_|SR providing storage for the PVS cache  |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VDI`               |`VDI ref`           |_RO/runtime_   |The VDI used for caching                |

## RPCs associated with class: PVS&#95;cache&#95;storage

### RPC name: create

_Overview:_

Create a new PVS&#95;cache&#95;storage instance, and return its handle.

_Signature:_

```
PVS_cache_storage ref create (session ref session_ref, PVS_cache_storage record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage record`    |`args`                        |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_cache_storage ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified PVS&#95;cache&#95;storage instance.

_Signature:_

```
void destroy (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;cache&#95;storages known to the system.

_Signature:_

```
PVS_cache_storage ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;cache&#95;storage references to PVS&#95;cache&#95;storage records for all PVS&#95;cache&#95;storages known to the system.

_Signature:_

```
(PVS_cache_storage ref -> PVS_cache_storage record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PVS_cache_storage ref -> PVS_cache_storage record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;cache&#95;storage instance with the specified UUID.

_Signature:_

```
PVS_cache_storage ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage ref`

reference to the object

### RPC name: get&#95;host

_Overview:_

Get the host field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
host ref get_host (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;cache&#95;storage.

_Signature:_

```
PVS_cache_storage record get_record (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage record`

all fields from the object

### RPC name: get&#95;site

_Overview:_

Get the site field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
PVS_site ref get_site (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

value of the field

### RPC name: get&#95;size

_Overview:_

Get the size field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
int get_size (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;SR

_Overview:_

Get the SR field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
SR ref get_SR (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
string get_uuid (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VDI

_Overview:_

Get the VDI field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
VDI ref get_VDI (session ref session_ref, PVS_cache_storage ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_cache_storage ref`       |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field
