# Class: VBD

A virtual block device

## Fields for class: VBD

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`vbd_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`bootable`          |`bool`              |_RW_           |true if this VBD is bootable            |
|`current_operations`|`(string -> vbd_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`currently_attached`|`bool`              |_RO/constructor_|is the device currently attached &#40;erased on reboot&#41;|
|`device`            |`string`            |_RO/constructor_|device seen by the guest e.g. hda1      |
|`empty`             |`bool`              |_RO/constructor_|if true this represents an empty drive  |
|`metrics`           |`VBD_metrics ref`   |_RO/runtime_   |**Removed.** metrics associated with this VBD        |
|`mode`              |`vbd_mode`          |_RO/constructor_|the mode the VBD should be mounted with |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`qos_algorithm_params`|`(string -> string) map`|_RW_           |parameters for chosen QoS algorithm     |
|`qos_algorithm_type`|`string`            |_RW_           |QoS algorithm to use                    |
|`qos_supported_algorithms`|`string set`        |_RO/runtime_   |supported QoS algorithms for this VBD   |
|`runtime_properties`|`(string -> string) map`|_RO/runtime_   |Device runtime properties               |
|`status_code`       |`int`               |_RO/runtime_   |error/success code associated with last attach&#45;operation &#40;erased on reboot&#41;|
|`status_detail`     |`string`            |_RO/runtime_   |error/success information associated with last attach&#45;operation status &#40;erased on reboot&#41;|
|`storage_lock`      |`bool`              |_RO/runtime_   |true if a storage level lock was acquired|
|`type`              |`vbd_type`          |_RW_           |how the VBD will appear to the guest &#40;e.g. disk or CD&#41;|
|`unpluggable`       |`bool`              |_RW_           |true if this VBD will support hot&#45;unplug|
|`userdevice`        |`string`            |_RW_           |user&#45;friendly device name e.g. 0,1,2,etc.|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VDI`               |`VDI ref`           |_RO/constructor_|the virtual disk                        |
|`VM`                |`VM ref`            |_RO/constructor_|the virtual machine                     |

## RPCs associated with class: VBD

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VBD.

_Signature:_

```
void add_to_other_config (session ref session_ref, VBD ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: add&#95;to&#95;qos&#95;algorithm&#95;params

_Overview:_

Add the given key&#45;value pair to the qos/algorithm&#95;params field of the given VBD.

_Signature:_

```
void add_to_qos_algorithm_params (session ref session_ref, VBD ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: assert&#95;attachable

_Overview:_

Throws an error if this VBD could not be attached to this VM if the VM were running. Intended for debugging.

_Signature:_

```
void assert_attachable (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |The VBD to query                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new VBD instance, and return its handle.

_Signature:_

```
VBD ref create (session ref session_ref, VBD record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD record`                  |`args`                        |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VBD ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified VBD instance.

_Signature:_

```
void destroy (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: eject

_Overview:_

Remove the media from the device and leave it empty

_Signature:_

```
void eject (session ref session_ref, VBD ref vbd)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`vbd`                         |The vbd representing the CDROM&#45;like device|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VBD_NOT_REMOVABLE_MEDIA`, `VBD_IS_EMPTY`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VBDs known to the system.

_Signature:_

```
VBD ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VBD ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VBD references to VBD records for all VBDs known to the system.

_Signature:_

```
(VBD ref -> VBD record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VBD ref -> VBD record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VBD.

_Signature:_

```
vbd_operations set get_allowed_operations (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vbd_operations set`

value of the field

### RPC name: get&#95;bootable

_Overview:_

Get the bootable field of the given VBD.

_Signature:_

```
bool get_bootable (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VBD instance with the specified UUID.

_Signature:_

```
VBD ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VBD ref`

reference to the object

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VBD.

_Signature:_

```
(string -> vbd_operations) map get_current_operations (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vbd_operations) map`

value of the field

### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VBD.

_Signature:_

```
bool get_currently_attached (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;device

_Overview:_

Get the device field of the given VBD.

_Signature:_

```
string get_device (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;empty

_Overview:_

Get the empty field of the given VBD.

_Signature:_

```
bool get_empty (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;metrics

**This message is removed.**

_Overview:_

Get the metrics field of the given VBD.

_Signature:_

```
VBD_metrics ref get_metrics (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD_metrics ref`

value of the field

### RPC name: get&#95;mode

_Overview:_

Get the mode field of the given VBD.

_Signature:_

```
vbd_mode get_mode (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vbd_mode`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VBD.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;qos&#95;algorithm&#95;params

_Overview:_

Get the qos/algorithm&#95;params field of the given VBD.

_Signature:_

```
(string -> string) map get_qos_algorithm_params (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;qos&#95;algorithm&#95;type

_Overview:_

Get the qos/algorithm&#95;type field of the given VBD.

_Signature:_

```
string get_qos_algorithm_type (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;qos&#95;supported&#95;algorithms

_Overview:_

Get the qos/supported&#95;algorithms field of the given VBD.

_Signature:_

```
string set get_qos_supported_algorithms (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VBD.

_Signature:_

```
VBD record get_record (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD record`

all fields from the object

### RPC name: get&#95;runtime&#95;properties

_Overview:_

Get the runtime&#95;properties field of the given VBD.

_Signature:_

```
(string -> string) map get_runtime_properties (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;status&#95;code

_Overview:_

Get the status&#95;code field of the given VBD.

_Signature:_

```
int get_status_code (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;status&#95;detail

_Overview:_

Get the status&#95;detail field of the given VBD.

_Signature:_

```
string get_status_detail (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;storage&#95;lock

_Overview:_

Get the storage&#95;lock field of the given VBD.

_Signature:_

```
bool get_storage_lock (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given VBD.

_Signature:_

```
vbd_type get_type (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vbd_type`

value of the field

### RPC name: get&#95;unpluggable

_Overview:_

Get the unpluggable field of the given VBD.

_Signature:_

```
bool get_unpluggable (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;userdevice

_Overview:_

Get the userdevice field of the given VBD.

_Signature:_

```
string get_userdevice (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VBD.

_Signature:_

```
string get_uuid (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VDI

_Overview:_

Get the VDI field of the given VBD.

_Signature:_

```
VDI ref get_VDI (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VBD.

_Signature:_

```
VM ref get_VM (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

### RPC name: insert

_Overview:_

Insert new media into the device

_Signature:_

```
void insert (session ref session_ref, VBD ref vbd, VDI ref vdi)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`vbd`                         |The vbd representing the CDROM&#45;like device|
|`VDI ref`                     |`vdi`                         |The new VDI to 'insert'                 |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VBD_NOT_REMOVABLE_MEDIA`, `VBD_NOT_EMPTY`

### RPC name: plug

_Overview:_

Hotplug the specified VBD, dynamically attaching it to the running VM

_Signature:_

```
void plug (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |The VBD to hotplug                      |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VBD.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VBD ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;qos&#95;algorithm&#95;params

_Overview:_

Remove the given key and its corresponding value from the qos/algorithm&#95;params field of the given VBD.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_qos_algorithm_params (session ref session_ref, VBD ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;bootable

_Overview:_

Set the bootable field of the given VBD.

_Signature:_

```
void set_bootable (session ref session_ref, VBD ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;mode

_Overview:_

Sets the mode of the VBD. The power&#95;state of the VM must be halted.

_Signature:_

```
void set_mode (session ref session_ref, VBD ref self, vbd_mode value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |Reference to the object                 |
|`vbd_mode`                    |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VBD.

_Signature:_

```
void set_other_config (session ref session_ref, VBD ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;qos&#95;algorithm&#95;params

_Overview:_

Set the qos/algorithm&#95;params field of the given VBD.

_Signature:_

```
void set_qos_algorithm_params (session ref session_ref, VBD ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;qos&#95;algorithm&#95;type

_Overview:_

Set the qos/algorithm&#95;type field of the given VBD.

_Signature:_

```
void set_qos_algorithm_type (session ref session_ref, VBD ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;type

_Overview:_

Set the type field of the given VBD.

_Signature:_

```
void set_type (session ref session_ref, VBD ref self, vbd_type value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`vbd_type`                    |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;unpluggable

_Overview:_

Set the unpluggable field of the given VBD.

_Signature:_

```
void set_unpluggable (session ref session_ref, VBD ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;userdevice

_Overview:_

Set the userdevice field of the given VBD.

_Signature:_

```
void set_userdevice (session ref session_ref, VBD ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: unplug

_Overview:_

Hot&#45;unplug the specified VBD, dynamically unattaching it from the running VM

_Signature:_

```
void unplug (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |The VBD to hot&#45;unplug               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `DEVICE_DETACH_REJECTED`, `DEVICE_ALREADY_DETACHED`

### RPC name: unplug&#95;force

_Overview:_

Forcibly unplug the specified VBD

_Signature:_

```
void unplug_force (session ref session_ref, VBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VBD ref`                     |`self`                        |The VBD to forcibly unplug              |

_Minimum Role:_ vm-admin

_Return Type:_ `void`
